@@ -92,7 +92,7 @@ from functools import total_ordering
 from gzip import GzipFile
 
 from CedarBackup3.config import VALID_COMPRESS_MODES
-from CedarBackup3.util import ObjectTypeList, changeOwnership, executeCommand, resolveCommand
+from CedarBackup3.util import ObjectTypeList, changeOwnership, executeCommand, pathJoin, resolveCommand
 from CedarBackup3.xmlutil import (
     addBooleanNode,
     addContainerNode,
@@ -652,9 +652,9 @@ def _getOutputFile(targetDir, database, compressMode):
         Tuple of (Output file object, filename), file opened in binary mode for use with executeCommand()
     """
     if database is None:
-        filename = os.path.join(targetDir, "mysqldump.txt")
+        filename = pathJoin(targetDir, "mysqldump.txt")
     else:
-        filename = os.path.join(targetDir, "mysqldump-%s.txt" % database)
+        filename = pathJoin(targetDir, "mysqldump-%s.txt" % database)
     if compressMode == "gzip":
         filename = "%s.gz" % filename
         outputFile = GzipFile(filename, "wb")
