@@ -112,7 +112,7 @@ from CedarBackup3.testutil import (
     findResources,
     removedir,
 )
-from CedarBackup3.util import UNIT_BYTES, UNIT_GBYTES, UNIT_KBYTES, UNIT_MBYTES
+from CedarBackup3.util import UNIT_BYTES, UNIT_GBYTES, UNIT_KBYTES, UNIT_MBYTES, pathJoin
 from CedarBackup3.xmlutil import createOutputDom, serializeDom
 
 #######################################################################
@@ -912,27 +912,27 @@ class TestFunctions(unittest.TestCase):
         self.extractTar("tree21")
         dailyDir = self.buildPath(["tree21", "2007", "01", "01"])
         self.assertTrue(os.path.exists(dailyDir) and os.path.isdir(dailyDir))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file001.a.b")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file001.a.b")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file003")))
         sizeLimit = ByteQuantity("1.0", UNIT_MBYTES)
         splitSize = ByteQuantity("100000", UNIT_BYTES)
         _splitDailyDir(dailyDir, sizeLimit, splitSize, None, None)
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file001.a.b")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file001.a.b")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file003")))
 
     def testSplitDailyDir_003(self):
         """
@@ -941,29 +941,29 @@ class TestFunctions(unittest.TestCase):
         self.extractTar("tree21")
         dailyDir = self.buildPath(["tree21", "2007", "01", "01"])
         self.assertTrue(os.path.exists(dailyDir) and os.path.isdir(dailyDir))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file001.a.b")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file001.a.b")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file003")))
         sizeLimit = ByteQuantity("100000", UNIT_BYTES)
         splitSize = ByteQuantity("10", UNIT_KBYTES)
         _splitDailyDir(dailyDir, sizeLimit, splitSize, None, None)
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file001.a.b")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file002")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system1", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file002")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system3", "file003")))
-        self.checkSplit(os.path.join(dailyDir, "system1", "file003"), 320000, 10 * 1024)
-        self.checkSplit(os.path.join(dailyDir, "system3", "file003"), 100001, 10 * 1024)
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file001.a.b")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file002")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system1", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file002")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system3", "file003")))
+        self.checkSplit(pathJoin(dailyDir, "system1", "file003"), 320000, 10 * 1024)
+        self.checkSplit(pathJoin(dailyDir, "system3", "file003"), 100001, 10 * 1024)
 
     def testSplitDailyDir_004(self):
         """
@@ -972,31 +972,31 @@ class TestFunctions(unittest.TestCase):
         self.extractTar("tree21")
         dailyDir = self.buildPath(["tree21", "2007", "01", "01"])
         self.assertTrue(os.path.exists(dailyDir) and os.path.isdir(dailyDir))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file001.a.b")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file001.a.b")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file003")))
         sizeLimit = ByteQuantity("99999", UNIT_BYTES)
         splitSize = ByteQuantity("5000", UNIT_BYTES)
         _splitDailyDir(dailyDir, sizeLimit, splitSize, None, None)
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file001.a.b")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file002")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system1", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file002")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system2", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file001")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system3", "file002")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system3", "file003")))
-        self.checkSplit(os.path.join(dailyDir, "system1", "file003"), 320000, 5000)
-        self.checkSplit(os.path.join(dailyDir, "system2", "file003"), 100000, 5000)
-        self.checkSplit(os.path.join(dailyDir, "system3", "file002"), 100000, 5000)
-        self.checkSplit(os.path.join(dailyDir, "system3", "file003"), 100001, 5000)
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file001.a.b")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file002")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system1", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file002")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system2", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file001")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system3", "file002")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system3", "file003")))
+        self.checkSplit(pathJoin(dailyDir, "system1", "file003"), 320000, 5000)
+        self.checkSplit(pathJoin(dailyDir, "system2", "file003"), 100000, 5000)
+        self.checkSplit(pathJoin(dailyDir, "system3", "file002"), 100000, 5000)
+        self.checkSplit(pathJoin(dailyDir, "system3", "file003"), 100001, 5000)
 
     def testSplitDailyDir_005(self):
         """
@@ -1005,33 +1005,33 @@ class TestFunctions(unittest.TestCase):
         self.extractTar("tree21")
         dailyDir = self.buildPath(["tree21", "2007", "01", "01"])
         self.assertTrue(os.path.exists(dailyDir) and os.path.isdir(dailyDir))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file001.a.b")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file001.a.b")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file003")))
         sizeLimit = ByteQuantity("10000.0", UNIT_BYTES)
         splitSize = ByteQuantity("2500", UNIT_BYTES)
         _splitDailyDir(dailyDir, sizeLimit, splitSize, None, None)
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file001.a.b")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system1", "file002")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system1", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file002")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system2", "file003")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system3", "file001")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system3", "file002")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system3", "file003")))
-        self.checkSplit(os.path.join(dailyDir, "system1", "file002"), 32000, 2500)
-        self.checkSplit(os.path.join(dailyDir, "system1", "file003"), 320000, 2500)
-        self.checkSplit(os.path.join(dailyDir, "system2", "file003"), 100000, 2500)
-        self.checkSplit(os.path.join(dailyDir, "system3", "file001"), 99999, 2500)
-        self.checkSplit(os.path.join(dailyDir, "system3", "file002"), 100000, 2500)
-        self.checkSplit(os.path.join(dailyDir, "system3", "file003"), 100001, 2500)
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file001.a.b")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system1", "file002")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system1", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file002")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system2", "file003")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system3", "file001")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system3", "file002")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system3", "file003")))
+        self.checkSplit(pathJoin(dailyDir, "system1", "file002"), 32000, 2500)
+        self.checkSplit(pathJoin(dailyDir, "system1", "file003"), 320000, 2500)
+        self.checkSplit(pathJoin(dailyDir, "system2", "file003"), 100000, 2500)
+        self.checkSplit(pathJoin(dailyDir, "system3", "file001"), 99999, 2500)
+        self.checkSplit(pathJoin(dailyDir, "system3", "file002"), 100000, 2500)
+        self.checkSplit(pathJoin(dailyDir, "system3", "file003"), 100001, 2500)
 
     def testSplitDailyDir_006(self):
         """
@@ -1040,33 +1040,33 @@ class TestFunctions(unittest.TestCase):
         self.extractTar("tree21")
         dailyDir = self.buildPath(["tree21", "2007", "01", "01"])
         self.assertTrue(os.path.exists(dailyDir) and os.path.isdir(dailyDir))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file001.a.b")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file001.a.b")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file003")))
         sizeLimit = ByteQuantity("10000", UNIT_BYTES)
         splitSize = ByteQuantity("1.0", UNIT_KBYTES)
         _splitDailyDir(dailyDir, sizeLimit, splitSize, None, None)
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file001.a.b")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system1", "file002")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system1", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file002")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system2", "file003")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system3", "file001")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system3", "file002")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system3", "file003")))
-        self.checkSplit(os.path.join(dailyDir, "system1", "file002"), 32000, 1 * 1024)
-        self.checkSplit(os.path.join(dailyDir, "system1", "file003"), 320000, 1 * 1024)
-        self.checkSplit(os.path.join(dailyDir, "system2", "file003"), 100000, 1 * 1024)
-        self.checkSplit(os.path.join(dailyDir, "system3", "file001"), 99999, 1 * 1024)
-        self.checkSplit(os.path.join(dailyDir, "system3", "file002"), 100000, 1 * 1024)
-        self.checkSplit(os.path.join(dailyDir, "system3", "file003"), 100001, 1 * 1024)
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file001.a.b")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system1", "file002")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system1", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file002")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system2", "file003")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system3", "file001")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system3", "file002")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system3", "file003")))
+        self.checkSplit(pathJoin(dailyDir, "system1", "file002"), 32000, 1 * 1024)
+        self.checkSplit(pathJoin(dailyDir, "system1", "file003"), 320000, 1 * 1024)
+        self.checkSplit(pathJoin(dailyDir, "system2", "file003"), 100000, 1 * 1024)
+        self.checkSplit(pathJoin(dailyDir, "system3", "file001"), 99999, 1 * 1024)
+        self.checkSplit(pathJoin(dailyDir, "system3", "file002"), 100000, 1 * 1024)
+        self.checkSplit(pathJoin(dailyDir, "system3", "file003"), 100001, 1 * 1024)
 
     def testSplitDailyDir_007(self):
         """
@@ -1075,31 +1075,31 @@ class TestFunctions(unittest.TestCase):
         self.extractTar("tree21")
         dailyDir = self.buildPath(["tree21", "2007", "01", "01"])
         self.assertTrue(os.path.exists(dailyDir) and os.path.isdir(dailyDir))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file001.a.b")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file001")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file002")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system3", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file001.a.b")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file001")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file002")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system3", "file003")))
         sizeLimit = ByteQuantity("9999", UNIT_BYTES)
         splitSize = ByteQuantity("1000", UNIT_BYTES)
         _splitDailyDir(dailyDir, sizeLimit, splitSize, None, None)
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system1", "file001.a.b")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system1", "file002")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system1", "file003")))
-        self.assertTrue(os.path.exists(os.path.join(dailyDir, "system2", "file001")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system2", "file002")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system2", "file003")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system3", "file001")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system3", "file002")))
-        self.assertFalse(os.path.exists(os.path.join(dailyDir, "system3", "file003")))
-        self.checkSplit(os.path.join(dailyDir, "system1", "file002"), 32000, 1000)
-        self.checkSplit(os.path.join(dailyDir, "system1", "file003"), 320000, 1000)
-        self.checkSplit(os.path.join(dailyDir, "system2", "file002"), 10000, 1000)
-        self.checkSplit(os.path.join(dailyDir, "system2", "file003"), 100000, 1000)
-        self.checkSplit(os.path.join(dailyDir, "system3", "file001"), 99999, 1000)
-        self.checkSplit(os.path.join(dailyDir, "system3", "file002"), 100000, 1000)
-        self.checkSplit(os.path.join(dailyDir, "system3", "file003"), 100001, 1000)
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system1", "file001.a.b")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system1", "file002")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system1", "file003")))
+        self.assertTrue(os.path.exists(pathJoin(dailyDir, "system2", "file001")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system2", "file002")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system2", "file003")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system3", "file001")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system3", "file002")))
+        self.assertFalse(os.path.exists(pathJoin(dailyDir, "system3", "file003")))
+        self.checkSplit(pathJoin(dailyDir, "system1", "file002"), 32000, 1000)
+        self.checkSplit(pathJoin(dailyDir, "system1", "file003"), 320000, 1000)
+        self.checkSplit(pathJoin(dailyDir, "system2", "file002"), 10000, 1000)
+        self.checkSplit(pathJoin(dailyDir, "system2", "file003"), 100000, 1000)
+        self.checkSplit(pathJoin(dailyDir, "system3", "file001"), 99999, 1000)
+        self.checkSplit(pathJoin(dailyDir, "system3", "file002"), 100000, 1000)
+        self.checkSplit(pathJoin(dailyDir, "system3", "file003"), 100001, 1000)
